@@ -29,12 +29,17 @@ def pretxncommit(ui, repo, hooktype, node, pending, **kwargs):
     files = ctx.files()
     msg = ctx.description()
 
+    filecontexts = list(ctx)
+
     # if the skip text is found in the message, skip the whole commit
     if skip_text in msg:
         return False
 
     warnings = 0
     for f in files:
+        if f not in filecontexts:
+            continue  # this file was removed
+
         filename = os.path.join(repo_path, f)
 
         # if the skip text is found in the file, skip it
